Overview
========

The nidaba-client package contains only the client and is supposed to be used
with an external API server. 

Documentation
=============

Want to learn more? `Read the
Docs <https:///openphilology.github.io/nidaba/>`__
